package dao;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import menu.Alcohol;

public class AlcoholDAO {

	private final String JDBC_URL = "jdbc:mysql://localhost:3307/orderApp?useSSL=false&useUnicode=true&characterEncoding=UTF-8";
	private final String DB_USER = "root";
	private final String DB_PASS = "";

	public AlcoholDAO() {
		try {
			Class.forName("com.mysql.jdbc.Driver");
		} catch (ClassNotFoundException e) {
			throw new  IllegalStateException("JDBCドライバを読み込めませんでした");
		}
	}

	public List<Alcohol> findAll() {

		List<Alcohol> alcoholList = new ArrayList<>();

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "SELECT ID,NAME,PRICE,DISCRIPTION,ISSOUR,ABV,DISPLAY FROM ALCOHOL ORDER BY ID DESC";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			ResultSet rs = pStmt.executeQuery();

			while (rs.next()) {
				int id = rs.getInt("ID");
				String name = rs.getString("NAME");
				int price = rs.getInt("PRICE");
				String discription = rs.getString("DISCRIPTION");
				boolean isSour = rs.getBoolean("ISSOUR");
				String abv = rs.getString("ABV");
				boolean display = rs.getBoolean("DISPLAY");
				Alcohol alcohol = new Alcohol(id, name, price, isSour, discription, abv, display);
				alcoholList.add(alcohol);
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("AlcoholDAO.java：ALCOHOLテーブルを取得できません。");
			return null;
		}

		return alcoholList;

	}

	public boolean addAlcohol(Alcohol alcohol) {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "INSERT INTO ALCOHOL(ID, NAME, PRICE, DISCRIPTION, ISSOUR, ABV, DISPLAY) VALUES(NULL, ?, ?, ?, ?, ?, ?)";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setString(1, alcohol.getName());
			pStmt.setInt(2, alcohol.getPrice());
			pStmt.setString(3, alcohol.getDiscription());
			pStmt.setBoolean(4, alcohol.isSour());
			pStmt.setString(5, alcohol.getAbv());
			pStmt.setBoolean(6, alcohol.getDisplay());

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("AlcoholDAO.java：DBにアルコールを登録できません。");
			return false;
		}

		return true;

	}

	public boolean deleteAlcohol(int id) {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "DELETE FROM ALCOHOL WHERE ID = ?";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setInt(1, id);

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("AlcoholDAO.java：DBからアルコールを削除できません。");
			return false;
		}

		return true;

	}

	public boolean switchDisplay(int id, boolean isDisplay) {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "UPDATE ALCOHOL SET DISPLAY = ? WHERE ID = ?";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setBoolean(1, isDisplay);
			pStmt.setInt(2, id);

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("AlcoholDAO.java：DBのアルコール表示切替ができません。");
			return false;
		}

		return true;

	}

	public boolean checkTable() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "SELECT ID,NAME,PRICE,DISCRIPTION,ISSOUR,ABV,DISPLAY FROM ALCOHOL ORDER BY ID DESC";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			pStmt.executeQuery();

		} catch (SQLException e) {
			e.printStackTrace();
			return false;
		}

		return true;

	}

	public boolean createTable() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "CREATE TABLE ALCOHOL ("
						+ "ID INT PRIMARY KEY AUTO_INCREMENT, "
						+ "NAME VARCHAR(100), "
						+ "PRICE INT, "
						+ "DISCRIPTION VARCHAR(255), "
						+ "ISSOUR TINYINT(1), "
						+ "ABV VARCHAR(5), "
						+ "DISPLAY TINYINT(1)"
						+ ")";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			pStmt.executeUpdate();

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("AlcoholDAO.java：ALCOHOLテーブルを作成できません。");
			return false;
		}

		return true;

	}
}