package dao;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import model.Customer;

public class CustomerDAO {

	private final String JDBC_URL = "jdbc:mysql://localhost:3307/orderApp?useSSL=false&useUnicode=true&characterEncoding=UTF-8";
	private final String DB_USER = "root";
	private final String DB_PASS = "";

	public CustomerDAO() {
		try {
			Class.forName("com.mysql.jdbc.Driver");
		} catch (ClassNotFoundException e) {
			throw new  IllegalStateException("JDBCドライバを読み込めませんでした");
		}
	}

	public List<Customer> findAll() {

		List<Customer> customerList = new ArrayList<>();

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "SELECT ID,SEATNAME,TIME,PRICE FROM CUSTOMER ORDER BY TIME DESC";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			ResultSet rs = pStmt.executeQuery();

			while (rs.next()) {
				String id = Integer.toString(rs.getInt("ID"));
				String seatName = rs.getString("SEATNAME");
				String time = rs.getString("TIME");
				String price = rs.getString("PRICE");
				Customer customer = new Customer(id, seatName , time, price);
				customerList.add(customer);
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("CustomerDAO.java：CUSTOMERテーブルを取得できません。");
			return null;
		}

		return customerList;

	}

	public boolean addCustomer(Customer customer) {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "INSERT INTO CUSTOMER(ID, SEATNAME, TIME, PRICE) VALUES(NULL, ?, ?, ?)";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setString(1, customer.getSeatName());
			pStmt.setString(2, customer.getPrice());
			pStmt.setString(3, customer.getTime());

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("CustomerDAO.java：DBに顧客情報を追加できません。");
			System.out.println("エラー："
					+ " ID：" + customer.getId() + " 座席名：" + customer.getSeatName() + " 金額：" + customer.getPrice() + "円 時間：" + customer.getTime());
			return false;
		}

		return true;

	}

	public boolean clearTable() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "TRUNCATE CUSTOMER";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			int result = pStmt.executeUpdate();
			System.out.println("通知：顧客履歴を削除");
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("CustomerDAO.java：CUSTOMERテーブルをリセットできません。");
			return false;
		}

		return true;

	}

	public boolean checkTable() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "SELECT ID,SEATNAME,TIME,PRICE FROM CUSTOMER ORDER BY ID DESC";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			pStmt.executeQuery();

		} catch (SQLException e) {
			e.printStackTrace();
			return false;
		}

		return true;

	}

	public boolean createTable() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "CREATE TABLE CUSTOMER ("
						+ "ID INT PRIMARY KEY AUTO_INCREMENT, "
						+ "SEATNAME VARCHAR(100), "
						+ "TIME VARCHAR(255), "
						+ "PRICE VARCHAR(255) "
						+ ")";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			pStmt.executeUpdate();

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("CustomerDAO.java：CUSTOMERテーブルを作成できません。");
			return false;
		}

		return true;

	}
}