package dao;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import model.Employee;
import model.Login;

public class EmployeesDAO {

	private final String JDBC_URL = "jdbc:mysql://localhost:3307/orderApp?useSSL=false&useUnicode=true&characterEncoding=UTF-8";
	private final String DB_USER = "root";
	private final String DB_PASS = "";

	public EmployeesDAO() {
		try {
			Class.forName("com.mysql.jdbc.Driver");
		} catch (ClassNotFoundException e) {
			throw new IllegalStateException("JDBCドライバを読み込めませんでした");
		}
	}

	public Employee findByLogin(Login login) {

		Employee employee = null;

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER,DB_PASS)) {
			String sql = "SELECT NAME, ID, PASS, POSITION FROM EMPLOYEES WHERE ID = ? AND PASS = ?";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			pStmt.setString(1, login.getId());
			pStmt.setString(2, login.getPass());

			ResultSet rs = pStmt.executeQuery();

			if (rs.next()) {
				String name = rs.getString("NAME");
				String id = rs.getString("ID");
				String pass = rs.getString("PASS");
				String position = rs.getString("POSITION");
				employee = new Employee(name, id, pass, position);
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("EmployeesDAO.java：ログイン処理エラー。");
			return null;
		}

		return employee;

	}

	public List<Employee> findAll() {

		List<Employee> employeeList = new ArrayList<>();

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "SELECT NAME,ID,PASS,POSITION FROM EMPLOYEES ORDER BY ID DESC";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			ResultSet rs = pStmt.executeQuery();

			while (rs.next()) {
				String name = rs.getString("NAME");
				String id = rs.getString("ID");
				String pass = rs.getString("PASS");
				String position = rs.getString("POSITION");
				Employee employee= new Employee(name, id, pass, position);
				employeeList.add(employee);
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("EmployeesDAO.java：EMPLOYEESテーブルを取得できません。");
			return null;
		}

		return employeeList;

	}

	public Employee findEmployee(String loginId) {

		Employee employee = null;

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "SELECT NAME, ID, PASS, POSITION FROM EMPLOYEES WHERE ID = ?";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setString(1, loginId);
			ResultSet rs = pStmt.executeQuery();

			while (rs.next()) {
				String name = rs.getString("NAME");
				String id = rs.getString("ID");
				String pass = rs.getString("PASS");
				String position = rs.getString("POSITION");
				employee = new Employee(name,id,pass,position);
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("EmployeesDAO.java：ログイン対象のユーザーを取得できません。");
			return null;
		}

		return employee;

	}

	public boolean addEmployee(Employee employee) {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "INSERT INTO EMPLOYEES(NAME, ID, PASS, POSITION) VALUES(?, ?, ?, ?)";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setString(1, employee.getName());
			pStmt.setString(2, employee.getId());
			pStmt.setString(3, employee.getPass());
			pStmt.setString(4, employee.getPosition());

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("EmployeesDAO.java：DBに従業員情報を登録できません。");
			return false;
		}

		return true;

	}

	public boolean deleteEmployee(String id) {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "DELETE FROM EMPLOYEES WHERE ID = ?";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setString(1, id);

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("EmployeesDAO.java：DBから従業員情報を削除できません。");
			return false;
		}

		return true;

	}

	public boolean checkTable() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "SELECT NAME,ID,PASS,POSITION FROM EMPLOYEES ORDER BY ID DESC";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			pStmt.executeQuery();

		} catch (SQLException e) {
			e.printStackTrace();
			return false;
		}

		return true;

	}

	public boolean createTable() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "CREATE TABLE EMPLOYEES ("
						+ "NAME VARCHAR(255), "
						+ "ID VARCHAR(255), "
						+ "PASS VARCHAR(255), "
						+ "POSITION VARCHAR(255) "
						+ ")";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			pStmt.executeUpdate();

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("EmployeesDAO.java：EMPLOYEESテーブルを作成できません。");
			return false;
		}

		return true;

	}
}