package dao;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import menu.Food;
import model.CheckVariableLogic;

public class FoodDAO {

	private final String JDBC_URL = "jdbc:mysql://localhost:3307/orderApp?useSSL=false&useUnicode=true&characterEncoding=UTF-8";
	private final String DB_USER = "root";
	private final String DB_PASS = "";

	public FoodDAO() {
		try {
			Class.forName("com.mysql.jdbc.Driver");
		} catch (ClassNotFoundException e) {
			throw new  IllegalStateException("JDBCドライバを読み込めませんでした");
		}
	}

	public List<Food> findAll() {

		List<Food> foodList = new ArrayList<>();

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "SELECT ID,NAME,PRICE,DISCRIPTION,DISPLAY FROM FOOD ORDER BY ID DESC";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			ResultSet rs = pStmt.executeQuery();

			while (rs.next()) {
				int id = rs.getInt("ID");
				String name = rs.getString("NAME");
				int price = rs.getInt("PRICE");
				String discription = rs.getString("DISCRIPTION");
				boolean display = rs.getBoolean("DISPLAY");
				Food food = new Food(id, name, price, discription, display);

				String method = Thread.currentThread().getStackTrace()[1].getMethodName();
				CheckVariableLogic cvl = new CheckVariableLogic();
				if (!cvl.checkFood(food, method)) System.exit(0);

				foodList.add(food);
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("FoodDAO.java：FOODテーブルを取得できません。");
			return null;
		}

		return foodList;

	}

	public boolean addFood(Food food) {

		String method = Thread.currentThread().getStackTrace()[1].getMethodName();
		CheckVariableLogic cvl = new CheckVariableLogic();
		if (cvl.checkFood(food, method)) System.out.println("エラー：変数の値が正しくありません。");

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "INSERT INTO FOOD(ID, NAME, PRICE, DISCRIPTION, DISPLAY) VALUES(NULL, ?, ?, ?, ?)";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setString(1, food.getName());
			pStmt.setInt(2, food.getPrice());
			pStmt.setString(3, food.getDiscription());
			pStmt.setBoolean(4, food.getDisplay());

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("FoodDAO.java：DBに食べ物を登録できません。");
			return false;
		}

		return true;

	}

	public boolean deleteFood(int id) {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "DELETE FROM FOOD WHERE ID = ?";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setInt(1, id);

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("FoodDAO.java：DBから食べ物を削除できません。");
			return false;
		}

		return true;

	}

	public boolean switchDisplay(int id, boolean isDisplay) {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "UPDATE FOOD SET DISPLAY = ? WHERE ID = ?";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setBoolean(1, isDisplay);
			pStmt.setInt(2, id);

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("FoodDAO.java：DBの食べ物表示切替ができません。");
			return false;
		}

		return true;

	}

	public boolean checkTable() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "SELECT ID,NAME,PRICE,DISCRIPTION,DISPLAY FROM FOOD ORDER BY ID DESC";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			pStmt.executeQuery();

		} catch (SQLException e) {
			e.printStackTrace();
			return false;
		}

		return true;

	}

	public boolean createTable() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "CREATE TABLE FOOD ("
						+ "ID INT PRIMARY KEY AUTO_INCREMENT, "
						+ "NAME VARCHAR(50), "
						+ "PRICE INT, "
						+ "DISCRIPTION VARCHAR(255), "
						+ "DISPLAY TINYINT(1) "
						+ ")";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			pStmt.executeUpdate();

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("FoodDAO.java：FOODテーブルを作成できません。");
			return false;
		}

		return true;

	}
}