package dao;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import seat.Seat;

public class SeatDAO {

	private final String JDBC_URL = "jdbc:mysql://localhost:3307/orderApp?useSSL=false&useUnicode=true&characterEncoding=UTF-8";
	private final String DB_USER = "root";
	private final String DB_PASS = "";

	public SeatDAO() {
		try {
			Class.forName("com.mysql.jdbc.Driver");
		} catch (ClassNotFoundException e) {
			throw new IllegalStateException("JDBCドライバを読み込めませんでした");
		}
	}

	public List<Seat> findSeat() {

		List<Seat> seatList = new ArrayList<>();

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER,DB_PASS)) {
			String sql = "SELECT ID, SEATNAME, PRICE, USED FROM SEAT ORDER BY ID DESC";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			ResultSet rs = pStmt.executeQuery();

			while (rs.next()) {
				String id = rs.getString("ID");
				String seatName = rs.getString("SEATNAME");
				int price = rs.getInt("PRICE");
				boolean used = rs.getBoolean("USED");
				Seat seat = new Seat();
				seat.setId(id);
				seat.setSeatNumber(seatName);
				seat.setPrice(price);
				seat.setUsed(used);
				seatList.add(seat);
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("SeatDAO.java：SEATテーブルを取得できません。");
			return null;
		}

		return seatList;

	}

	public boolean addSeat(String seatName) {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "INSERT INTO SEAT(ID, SEATNAME, PRICE, USED) VALUES(NULL, ?, 0, 0)";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setString(1, seatName);

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("SeatDAO.java：DBに座席情報を登録できません。");
			return false;
		}

		return true;

	}

	public boolean deleteSeat(int id) {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "DELETE FROM SEAT WHERE ID = ?";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setInt(1, id);

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("SeatDAO.java：DBから座席情報を削除できません。");
			return false;
		}

		return true;

	}

	public boolean updateSeat(Seat seat) {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "UPDATE SEAT SET PRICE = ?, USED = ? WHERE ID = ?";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setInt(1, seat.getPrice());
			pStmt.setBoolean(2, seat.isUsed());
			pStmt.setInt(3, Integer.parseInt(seat.getId()));

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("SeatDAO.java：DBの座席情報を更新できません。");
			return false;
		}

		return true;

	}

	public boolean checkTable() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER,DB_PASS)) {
			String sql = "SELECT ID, SEATNAME, PRICE, USED FROM SEAT ORDER BY ID DESC";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			pStmt.executeQuery();

		} catch (SQLException e) {
			e.printStackTrace();
			return false;
		}

		return true;

	}

	public boolean createTable() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "CREATE TABLE SEAT ("
						+ "ID INT PRIMARY KEY AUTO_INCREMENT, "
						+ "SEATNAME VARCHAR(100), "
						+ "PRICE INT DEFAULT 0,"
						+ "USED TINYINT(1) DEFAULT 0"
						+ ")";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			pStmt.executeUpdate();

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("SeatDAO.java：SEATテーブルを作成できません。");
			return false;
		}

		return true;

	}

	public boolean resetSeat() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "UPDATE SEAT SET USED = FALSE";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("SeatDAO.java：DBの着席状況をリセットできません。");
			return false;
		}

		return true;

	}
}