package dao;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import menu.SoftDrink;
import model.CheckVariableLogic;

public class SoftDrinkDAO {

	private final String JDBC_URL = "jdbc:mysql://localhost:3307/orderApp?useSSL=false&useUnicode=true&characterEncoding=UTF-8";
	private final String DB_USER = "root";
	private final String DB_PASS = "";

	public SoftDrinkDAO() {
		try {
			Class.forName("com.mysql.jdbc.Driver");
		} catch (ClassNotFoundException e) {
			throw new  IllegalStateException("JDBCドライバを読み込めませんでした");
		}
	}

	public List<SoftDrink> findAll() {

		List<SoftDrink> softDrinkList = new ArrayList<>();

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "SELECT ID,NAME,PRICE,DISCRIPTION,ISSOUR,DISPLAY FROM SOFTDRINK ORDER BY ID DESC";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			ResultSet rs = pStmt.executeQuery();

			while (rs.next()) {
				int id = rs.getInt("ID");
				String name = rs.getString("NAME");
				int price = rs.getInt("PRICE");
				String discription = rs.getString("DISCRIPTION");
				boolean isSour = rs.getBoolean("ISSOUR");
				boolean display = rs.getBoolean("DISPLAY");
				SoftDrink softDrink = new SoftDrink(id, name, price, isSour, discription, display);

				String method = Thread.currentThread().getStackTrace()[1].getMethodName();
				CheckVariableLogic cvl = new CheckVariableLogic();
				if (!cvl.checkSoftDrink(softDrink, method)) System.exit(0);

				softDrinkList.add(softDrink);
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("SoftDrinkDAO.java：SOFTDRINKテーブルを取得できません。");
			return null;
		}

		return softDrinkList;

	}

	public boolean addSoftDrink(SoftDrink softDrink) {

		String method = Thread.currentThread().getStackTrace()[1].getMethodName();
		CheckVariableLogic cvl = new CheckVariableLogic();
		if (cvl.checkSoftDrink(softDrink, method)) System.out.println("エラー：変数の値が正しくありません。");

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "INSERT INTO SOFTDRINK(ID, NAME, PRICE, DISCRIPTION, ISSOUR, DISPLAY) VALUES( NULL, ?, ?, ?, ?, ?)";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setString(1, softDrink.getName());
			pStmt.setInt(2, softDrink.getPrice());
			pStmt.setString(3, softDrink.getDiscription());
			pStmt.setBoolean(4, softDrink.isSour());
			pStmt.setBoolean(5, softDrink.getDisplay());

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("SoftDrinkDAO.java：DBにソフトドリンクを登録できません。");
			return false;
		}

		return true;

	}

	public boolean deleteSoftDrink(int id) {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "DELETE FROM SOFTDRINK WHERE ID = ?";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setInt(1, id);

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("SoftDrinkDAO.java：DBからソフトドリンクを削除できません。");
			return false;
		}

		return true;

	}

	public boolean switchDisplay(int id, boolean isDisplay) {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "UPDATE SOFTDRINK SET DISPLAY = ? WHERE ID = ?";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setBoolean(1, isDisplay);
			pStmt.setInt(2, id);

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("SoftDrinkDAO.java：DBのソフトドリンク表示切替ができません。");
			return false;
		}

		return true;

	}

	public boolean checkTable() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "SELECT ID,NAME,PRICE,DISCRIPTION,ISSOUR,DISPLAY FROM SOFTDRINK ORDER BY ID DESC";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			pStmt.executeQuery();

		} catch (SQLException e) {
			e.printStackTrace();
			return false;
		}

		return true;

	}

	public boolean createTable() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "CREATE TABLE SOFTDRINK ("
						+ "ID INT PRIMARY KEY AUTO_INCREMENT, "
						+ "NAME VARCHAR(100), "
						+ "PRICE INT, "
						+ "DISCRIPTION VARCHAR(255), "
						+ "ISSOUR TINYINT(1),"
						+ "DISPLAY TINYINT(1)"
						+ ")";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			pStmt.executeUpdate();

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("SoftDrinkDAO.java：SOFTDRINKテーブルを作成できません。");
			return false;
		}

		return true;

	}
}