package dao;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import model.StoreData;

public class StoreDataDAO {

	private final String JDBC_URL = "jdbc:mysql://localhost:3307/orderApp?useSSL=false&useUnicode=true&characterEncoding=UTF-8";
	private final String DB_USER = "root";
	private final String DB_PASS = "";

	public StoreDataDAO() {
		try {
			Class.forName("com.mysql.jdbc.Driver");
		} catch (ClassNotFoundException e) {
			throw new IllegalStateException("JDBCドライバを読み込めませんでした");
		}
	}

	public boolean checkTable() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER,DB_PASS)) {
			String sql = "SELECT STORENAME FROM STOREDATA";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			pStmt.executeQuery();

		} catch (SQLException e) {
			e.printStackTrace();
			return false;
		}

		return true;

	}

	public boolean createTable() {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {

			String sql = "CREATE TABLE STOREDATA ("
						+ "STORENAME VARCHAR(100) "
						+ ")";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			pStmt.executeUpdate();

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("StoreDataDAO.java：STOREDATAテーブルを作成できません。");
			return false;
		}

		return true;

	}

	public boolean updateStoreData(StoreData storeData) {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "UPDATE STOREDATA SET STORENAME = ?";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setString(1, storeData.getStoreName());

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("StoreDataDAO.java：DBの店舗情報を更新できません。");
			return false;
		}

		return true;

	}

	public StoreData getStoreData() {

		StoreData storeData = null;

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER,DB_PASS)) {
			String sql = "SELECT STORENAME FROM STOREDATA";
			PreparedStatement pStmt = conn.prepareStatement(sql);
			ResultSet rs = pStmt.executeQuery();

			while (rs.next()) {
				String storeName = rs.getString("STORENAME");
				storeData = new StoreData(storeName);
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("StoreDataDAO.java：STOREDATAテーブルを取得できません。");
			return null;
		}

		return storeData;

	}

	public boolean addStoreData(StoreData storeData) {

		try (Connection conn = DriverManager.getConnection(JDBC_URL, DB_USER, DB_PASS)) {
			String sql = "INSERT INTO STOREDATA(STORENAME) VALUES(?)";
			PreparedStatement pStmt = conn.prepareStatement(sql);

			pStmt.setString(1, storeData.getStoreName());

			int result = pStmt.executeUpdate();
			if (result != 1) {
				return false;
			}

		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("StoreDataDAO.java：DBに店舗情報を登録できません。");
			return false;
		}

		return true;

	}

}
