package listener;

import java.util.List;

import javax.servlet.ServletContext;
import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;
import javax.servlet.annotation.WebListener;

import dao.AlcoholDAO;
import dao.CustomerDAO;
import dao.EmployeesDAO;
import dao.FoodDAO;
import dao.SeatDAO;
import dao.SoftDrinkDAO;
import dao.StoreDataDAO;
import exception.ErrorCreateTableException;
import menu.Alcohol;
import menu.Food;
import menu.SoftDrink;
import model.Customer;
import model.CustomerLogic;
import model.Employee;
import model.StoreData;

@WebListener
public class CounterListener implements ServletContextListener {

    public void contextDestroyed(ServletContextEvent sce)  {

    	// 終了時にテキストファイルに顧客情報を書き込む
		ServletContext application = sce.getServletContext();
		String realPath = application.getRealPath("WEB-INF/customerData");
		System.out.println(realPath);

    	CustomerDAO dao = new CustomerDAO();
    	List<Customer> customerList = dao.findAll();

    	if (!customerList.isEmpty()) {
        	CustomerLogic cl = new CustomerLogic();
        	if (cl.createFile(customerList, realPath)) {
        		System.out.println("通知：顧客履歴をテキスト出力");
            	dao.clearTable();
        	}
    	} else {
    		System.out.println("通知：顧客履歴はありません。");
    	}
    	// -----

    	System.out.println("通知：アプリケーションを終了しました。");

    }

    public void contextInitialized(ServletContextEvent sce)  {

    	// 起動時に各テーブルを作成、テストデータを登録
    	FoodDAO foodDAO = new FoodDAO();
    	SoftDrinkDAO softDrinkDAO = new SoftDrinkDAO();
    	AlcoholDAO alcoholDAO = new AlcoholDAO();
    	EmployeesDAO employeesDAO = new EmployeesDAO();
    	SeatDAO seatDAO = new SeatDAO();
    	CustomerDAO customerDAO = new CustomerDAO();
    	StoreDataDAO storeDataDAO = new StoreDataDAO();

    	if (!foodDAO.checkTable()) {
    		if (foodDAO.createTable()){
    			Food testFood1 = new Food("TestFood1",100, "Test Discription", true);
    			Food testFood2 = new Food("TestFood2",200, "Test Discription", true);
    			Food testFood3 = new Food("TestFood3",300, "Test Discription", true);
    			foodDAO.addFood(testFood1);
    			foodDAO.addFood(testFood2);
    			foodDAO.addFood(testFood3);
    			System.out.println("通知：FOODテーブルのテストデータを登録しました。");
    		}else {
    			String errorMsg = "FOOD";
    			displayError(errorMsg);
    		}
    	}

    	if (!softDrinkDAO.checkTable()) {
    		if (softDrinkDAO.createTable()){
    			SoftDrink testSoftDrink1 = new SoftDrink("TestSoftDrink1",100, true, "Test Discription", true);
    			SoftDrink testSoftDrink2 = new SoftDrink("TestSoftDrink2",200, false, "Test Discription", true);
    			SoftDrink testSoftDrink3 = new SoftDrink("TestSoftDrink3",300, false, "Test Discription", true);
    			softDrinkDAO.addSoftDrink(testSoftDrink1);
    			softDrinkDAO.addSoftDrink(testSoftDrink2);
    			softDrinkDAO.addSoftDrink(testSoftDrink3);
    			System.out.println("通知：SOFTDRINKテーブルのテストデータを登録しました。");
    		}else {
    			String errorMsg = "SOFTDRINK";
    			displayError(errorMsg);
    		}
    	}

    	if (!alcoholDAO.checkTable()) {
    		if (alcoholDAO.createTable()){
    			Alcohol testAlcohol1 = new Alcohol("TestAlcohol1",100, true, "Test Discription", "40", true);
    			Alcohol testAlcohol2 = new Alcohol("TestAlcohol2",200, false, "Test Discription", "10", true);
    			Alcohol testAlcohol3 = new Alcohol("TestAlcohol3",300, false, "Test Discription", "5", true);
    			alcoholDAO.addAlcohol(testAlcohol1);
    			alcoholDAO.addAlcohol(testAlcohol2);
    			alcoholDAO.addAlcohol(testAlcohol3);
    			System.out.println("通知：ALCOHOLテーブルのテストデータを登録しました。");
    		}else {
    			String errorMsg = "ALCOHOL";
    			displayError(errorMsg);
    		}
    	}

    	if (!employeesDAO.checkTable()) {
    		if (employeesDAO.createTable()){
    			Employee testUser = new Employee("TestUser","admin", "password", "管理者");
    			employeesDAO.addEmployee(testUser);
    			System.out.println("通知：EMPLOYEESテーブルのテストデータを登録しました。");
    		}else {
    			String errorMsg = "EMPLOYEES";
    			displayError(errorMsg);
    		}
    	}

    	if (!seatDAO.checkTable()) {
    		if (seatDAO.createTable()){
    			seatDAO.addSeat("S1");
    			System.out.println("通知：SEATテーブルのテストデータを登録しました。");
    		}else {
    			String errorMsg = "SEAT";
    			displayError(errorMsg);
    		}
    	}

    	if (!storeDataDAO.checkTable()) {
    		if (storeDataDAO.createTable()){
    			StoreData storeData = new StoreData("StoreName");
    			storeDataDAO.addStoreData(storeData);
    		} else {
    			String errorMsg = "STOREDATA";
    			displayError(errorMsg);
    		}
    	}

    	if (!customerDAO.checkTable()) {
    		if (!customerDAO.createTable()) {
    			String errorMsg = "CUSTOMER";
    			displayError(errorMsg);
    		}
    	}
    	// -----

    	if (seatDAO.resetSeat()) System.out.println("通知：SEATテーブルの着席状況をリセットしました。");

    	System.out.println("通知：アプリケーションを起動しました。");

    }

    public void displayError(String errorMsg) {

    	try {
			throw new ErrorCreateTableException("CounterListener.java：" + errorMsg + "テーブルを作成できません。");
	    } catch (Exception e) {
	    	e.printStackTrace();
	    	System.out.println("エラー：終了します。");
	    	System.exit(0);
	    }

    }

}
