package model;

import dao.AlcoholDAO;
import dao.EmployeesDAO;
import dao.FoodDAO;
import dao.SeatDAO;
import dao.SoftDrinkDAO;
import menu.Alcohol;
import menu.Food;
import menu.FoodAndDrink;
import menu.SoftDrink;

public class OptionLogic {

	public boolean addMenu(FoodAndDrink menu) {
		if (menu instanceof Food) {
			Food food = (Food)menu;
			FoodDAO dao = new FoodDAO();
			return dao.addFood(food);
		} else if (menu instanceof SoftDrink) {
			SoftDrink softDrink = (SoftDrink)menu;
			SoftDrinkDAO dao = new SoftDrinkDAO();
			return dao.addSoftDrink(softDrink);
		} else if (menu instanceof Alcohol) {
			Alcohol alcohol = (Alcohol)menu;
			AlcoholDAO dao = new AlcoholDAO();
			return dao.addAlcohol(alcohol);
		} else {
			return false;
		}
	}

	public boolean addEmployee(Employee employee) {
		EmployeesDAO dao = new EmployeesDAO();
		return dao.addEmployee(employee);
	}

	public boolean deleteEmployee(String id) {
		EmployeesDAO dao = new EmployeesDAO();
		return dao.deleteEmployee(id);
	}

	public boolean addSeat(String seatName) {
		SeatDAO dao = new SeatDAO();
		return dao.addSeat(seatName);
	}

	public boolean deleteSeat(int id) {
		SeatDAO dao = new SeatDAO();
		return dao.deleteSeat(id);
	}

	public boolean checkText(String name, String id, String pass, String position) {
		boolean result = true;
		if (!name.matches("^[^\\p{P}\\p{S}]+$")) {
			System.out.println("名前");
			result = false;
		} else if (!id.matches("^[^\\p{P}\\p{S}]+$")) {
			System.out.println("ID");
			result = false;
		} else if (!pass.matches("^(?=.*[a-zA-Z\\d])[a-zA-Z\\d]{6,}$")) {
			System.out.println("pass");
			result = false;
		} else if (!position.equals("スタッフ") && !position.equals("管理人")) {
			System.out.println("ポジション");
			result = false;
		}
		return result;
	}

	public boolean switchMenu(String menuType, int menuId, boolean isDisplay) {
		switch (menuType) {
			case "food":
				FoodDAO foodDAO = new FoodDAO();
				if (foodDAO.switchDisplay(menuId, isDisplay)) return true;
				break;

			case "softDrink":
				SoftDrinkDAO softDrinkDAO = new SoftDrinkDAO();
				if (softDrinkDAO.switchDisplay(menuId, isDisplay)) return true;
				break;

			case "alcohol":
				AlcoholDAO alcoholDAO = new  AlcoholDAO();
				if (alcoholDAO.switchDisplay(menuId, isDisplay)) return true;
				break;
		}
		return false;
	}

	public boolean deleteMenu(String menuType, int menuId) {
		switch (menuType) {
			case "food":
				FoodDAO foodDAO = new FoodDAO();
				if (foodDAO.deleteFood(menuId)) return true;
				break;

			case "softDrink":
				SoftDrinkDAO softDrinkDAO = new SoftDrinkDAO();
				if (softDrinkDAO.deleteSoftDrink(menuId)) return true;
				break;

			case "alcohol":
				AlcoholDAO alcoholDAO = new AlcoholDAO();
				if (alcoholDAO.deleteAlcohol(menuId)) return true;
				break;
		}
		return false;
	}

	public FoodAndDrink CreateItem(String menuType, String addMenuName, int price, String discription, boolean display, boolean isSour, String abv) {
		FoodAndDrink item = null;
		switch (menuType) {
			case "food":
				item = new Food(addMenuName, price, discription, display);
				break;

			case "softDrink":
				item = new SoftDrink(addMenuName, price, isSour, discription, display);
				break;

			case "alcohol":
				item = new Alcohol(addMenuName, price, isSour, discription, abv, display);
				break;
		}
		return item;
	}

}
