package servlet;

import java.io.IOException;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import dao.StoreDataDAO;
import model.Employee;
import model.OptionLogic;
import model.StoreData;

@WebServlet("/OptionServlet")
public class OptionServlet extends HttpServlet {
	private static final long serialVersionUID = 1L;

	protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		RequestDispatcher dispatcher = request.getRequestDispatcher("WEB-INF/jsp/option.jsp");
		dispatcher.forward(request, response);
	}

	protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

		String action = request.getParameter("action");

		OptionLogic ol = new OptionLogic();

		String result = "入力が正しくありません。";
		request.setAttribute("result", result);
		RequestDispatcher dispatcher = request.getRequestDispatcher("WEB-INF/jsp/option.jsp");

		switch (action) {

			case "addMenu":
				try {
					String menuType = request.getParameter("menuType");
					String addMenuName = request.getParameter("name");
					int price= Integer.parseInt(request.getParameter("price"));
					String discription = request.getParameter("discription");
					boolean display = Boolean.valueOf(request.getParameter("display"));
					boolean isSour = Boolean.valueOf(request.getParameter("isSour"));
					String abv = request.getParameter("abv");

					if (ol.addMenu(ol.CreateItem(menuType, addMenuName, price, discription, display, isSour, abv))) {
						result = "メニューを追加しました。";
						System.out.println("通知：メニューをDBに登録しました。");
					}
					break;
				} catch (Exception e) {
					dispatcher.forward(request, response);
				}

			case "switchMenu":
				try {
					String switchMenuType = request.getParameter("menuType");
					int switchMenuId = Integer.parseInt(request.getParameter("switchMenuId"));
					boolean isDisplay = Boolean.valueOf(request.getParameter("isDisplay"));

					if (ol.switchMenu(switchMenuType, switchMenuId, isDisplay)) {
						result = "更新しました。";
						System.out.println("通知：メニューの表示を切り替えました。");
					}
					break;
				} catch (Exception e) {
					dispatcher.forward(request, response);
				}

			case "deleteMenu":
				try {
					String deleteMenuType = request.getParameter("menuType");
					int deleteMenuId = Integer.parseInt(request.getParameter("deleteMenu"));

					if (ol.deleteMenu(deleteMenuType, deleteMenuId)) {
						result = "メニューを削除しました。";
						System.out.println("通知：メニューをDBから削除しました。");
					}
					break;
				} catch (Exception e) {
					dispatcher.forward(request, response);
				}

			case "addEmployee":
				String addEmployeeName = request.getParameter("name");
				String id = request.getParameter("id");
				String pass = request.getParameter("pass");
				String position = request.getParameter("position");

				if (ol.checkText(addEmployeeName, id, pass, position)) {
					Employee employee = new Employee(addEmployeeName, id, pass, position);
					if (ol.addEmployee(employee)) result = "従業員を追加しました。";
					System.out.println("通知：従業員をDBに登録しました。");
				} else {
					result = "使用できない文字が含まれています。";
				}
				break;

			case "addEmployeeOnlyStuff":
				String osName = request.getParameter("name");
				String osId = request.getParameter("id");
				String osPass = request.getParameter("pass");
				String osPosition = request.getParameter("position");

				if (ol.checkText(osName, osId, osPass, osPosition)) {
					Employee osEmployee = new Employee(osName, osId, osPass, osPosition);
					if (ol.addEmployee(osEmployee)) {
						result = "登録完了しました。";
						System.out.println("通知：従業員をDBに登録しました。");
					}
				} else {
					result = "使用できない文字が含まれています。";
				}

				request.setAttribute("result", result);
				RequestDispatcher loginDispatcher = request.getRequestDispatcher("WEB-INF/jsp/registerForm.jsp");
				loginDispatcher.forward(request, response);
				break;

			case "deleteEmployee":
				String deleteEmployeeId = request.getParameter("deleteEmployeeId");
				if (ol.deleteEmployee(deleteEmployeeId)) {
					result = "従業員を削除しました。";
					System.out.println("通知：従業員をDBから削除しました。");
				}
				break;

			case "addSeat":
				String addSeatName = request.getParameter("addSeatName");
				if (ol.addSeat(addSeatName))  {
					result = "座席を追加しました。";
					System.out.println("通知：座席をDBに登録しました。");
				}
				break;

			case "deleteSeat":
				int deleteSeatId= Integer.parseInt(request.getParameter("deleteSeatId"));
				if (ol.deleteSeat(deleteSeatId)) {
					result = "座席を削除しました。";
					System.out.println("通知：座席をDBから削除しました。");
				}
				break;

			case "updateStoreData":
				String storeName = request.getParameter("storeName");
				ServletContext application = getServletContext();
				StoreData storeData = (StoreData)application.getAttribute("storeData");
				storeData.setStoreName(storeName);
				StoreDataDAO storeDataDAO = new StoreDataDAO();
				if (storeDataDAO.updateStoreData(storeData)) {
					result = "店舗情報を更新しました。";
					System.out.println("通知：DBの店舗情報を更新しました。");
				} else {
					System.out.println("エラー：DBの店舗情報を更新できません。");
				}
				break;

		}

		request.setAttribute("result", result);
		dispatcher.forward(request, response);
	}
}
